==> kcoloredit-1.9.0-kde4.1.0.tar.bz2: kcoloredit-1.9.0-kde4.1.0/src/widgets/colorselectors/colorselector.h <==
/*********************************************************************************
*  Copyright (C) 2008 by Percy Camilo Triveño Aucahuasi <orgyforever@gmail.com>  *
*                                                                                *
*  This program is free software; you can redistribute it and/or modify          *
*  it under the terms of the GNU General Public License as published by          *
*  the Free Software Foundation; either version 2 of the License, or             *
*  (at your option) any later version.                                           *
*                                                                                *
*  This program is distributed in the hope that it will be useful,               *
*  but WITHOUT ANY WARRANTY; without even the implied warranty of                *
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
*  GNU General Public License for more details.                                  *
*                                                                                *
*  You should have received a copy of the GNU General Public License             *
*  along with this program; if not, write to the                                 *
*  Free Software Foundation, Inc.,                                               *
*  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.                 *
*********************************************************************************/

#ifndef COLOR_SELECTOR_H
#define COLOR_SELECTOR_H

#include "kcoloreditpage.h"

class ColorSelector : public KColorEditPage
{
    Q_OBJECT

    public:
        ColorSelector(QWidget * parent = 0);

    public slots:
        virtual void setColor(const QColor & color);

    signals:
        void colorSelected(const QColor & color);
};

#endif // COLOR_SELECTOR_H

==> kcoloredit-2.0.0-kde4.4.0.tar.bz2: kcoloredit-2.0.0-kde4.4.0/src/widgets/colorselectors/colorselector.h <==
/*********************************************************************************
*  Copyright (C) 2009 by Percy Camilo T. Aucahuasi <percy.camilo.ta@gmail.com>   *
*                                                                                *
*  This program is free software; you can redistribute it and/or modify          *
*  it under the terms of the GNU General Public License as published by          *
*  the Free Software Foundation; either version 2 of the License, or             *
*  (at your option) any later version.                                           *
*                                                                                *
*  This program is distributed in the hope that it will be useful,               *
*  but WITHOUT ANY WARRANTY; without even the implied warranty of                *
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
*  GNU General Public License for more details.                                  *
*                                                                                *
*  You should have received a copy of the GNU General Public License             *
*  along with this program; if not, write to the                                 *
*  Free Software Foundation, Inc.,                                               *
*  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.                 *
*********************************************************************************/

#ifndef COLOR_SELECTOR_H
#define COLOR_SELECTOR_H

#include <QtGui/QWidget>

class ColorSelector : public QWidget
{
    Q_OBJECT

    public:
        ColorSelector(QWidget * parent = 0);

    public slots:
        virtual void setColor(const QColor & color);

    signals:
        void colorSelected(const QColor & color);
};

#endif // COLOR_SELECTOR_H
